** data already massaged with DATA step and put into;
** final format as shown in complex.treatdata;

proc print data=complex.treatdata(obs=20);
title 'complex.treatdata';
run;
 
** only need this proc template if you are going to use ODS RTF TEXT=;
** to put the TABLE caption on the report;
ods path work.templat(update)
         sashelp.tmplmst(read);
proc template;
  define style styles.utext;
  parent=styles.rtf;
  style usertext from usertext /
       just=c
       font_weight=bold
       font_face='Times New Roman'
       font_size=12pt
       foreground=brown
       protectspecialchars=off;
  end;
run;

%let ft1 = %str(All univariates with p <0.10 were entered into backward stepwise elimination. );
%let ft2 = %str(Education dropped but was forced back into final mv model to control; final model mv passed Hosmer and Lemeshow goodness-of -fit test.);
%let foottext = &ft1.&ft2;
%let tnum = 284;

proc sort data=complex.treatdata out=treatdata;
by Ord GrpV Type;
run;

options missing = ' ' center nodate nonumber orientation=portrait;
ods listing close;
ods rtf file='complex1_examp_alternate.rtf' style=styles.utext;
ods escapechar='~';

title  font='Times New Roman' h=10pt 'Proc Report Alternate Demographic Example';
footnote j=l font='Times New Roman' h=10pt 
  'This is Footnote 1: Numbers were changed from original study.';
footnote2 j=l font='Times New Roman' h=10pt 
  'Program: Complex_treatment.sas';

ods rtf text="Table 1: Multivariate Predictors of Outpatient Alcohol Treatment (n=&tnum)";
proc report data=work.treatdata nowd
     style(report)={cellpadding=8px font_face='Times New Roman'}
     style(header)={background=white font_face='Times New Roman'}
     style(column)={font_face='Times New Roman'};
     column Ord GrpV Type Variable n_N OR_CI p_val;
     define Ord /group noprint;
     define GrpV /group noprint;
     define Type / order noprint;
     define Variable / display 'Variable' style(header)={cellwidth=2in};
     define n_N /display 'N (%)' 
            style(header)={cellwidth=1in}
            style(column)={just=r rightmargin=3pt};
     define OR_CI /display 'OR (95% CI)' 
            style(header)={cellwidth=2in}
            style(column)={leftmargin=6pt};
     define p_val /display 'p-value' 
            style(header)={cellwidth=1in}
            style(column)={just=r rightmargin=3pt};
     break after Ord /;
     compute after Ord /
        style={cellheight=2pt font_size=2pt};
        line ' ';
     endcomp;
     compute Variable;
        if Type = '1Head' then do;
           call define(_COL_,'style',
                'style={font_weight=bold}');
        end;
        else do;
           call define(_COL_,'style',
                'style={leftmargin=12pt}');
        end;
     endcomp;

     compute after /
       style={just=l foreground=black font_size=10pt};
       line "%unquote(&foottext)";
     endcomp;
run;

ods rtf close;
title;
footnote;
ods listing;


