options center nodate nonumber;
proc format;
  value $wl 'W' = '+'
            'T' = '/'
            'L' = '-';
run;
%let home = ~S={font_size=30pt font_face='Bissantz SparkFonts 4 - Misc' foreground=green};
%let othr = ~S={font_size=30pt font_face='Bissantz SparkFonts 4 - Misc' foreground=cx999999};

data sasteams;
  length Division $10 TeamName $20 g1-g24 $1 sparkrec $24 divord $1
         sparkcolr $2000;
  drop i;
  array wl $ g1-g24;
  infile datalines dsd;
  input Division $ divord $ TeamName $ g1-g24 $;
  sparkwin = ' ';

  wins = 0;
  losses = 0;
  ties = 0;

  do i = 1 to 24 by 1;
    sparkrec = catt(sparkrec,put(wl(i),$wl.));
    if wl(i) = 'W' then wins = wins + 1;
    else if wl(i) = 'L' then losses = losses + 1;
    else if wl(i) = 'T' then ties = ties + 1;

    ** every odd-numbered game is a home game (green);
    ** every even-numbered game is field of diff team (gray);
    if mod(i,2) = 0 then do;
       sparkcolr = catt(sparkcolr,"&othr",put(wl(i),$wl.));
    end;
    else do;
       sparkcolr = catt(sparkcolr,"&home",put(wl(i),$wl.));
    end;
  end;

  output;

return;
datalines;
"Eastern",1,"SAS Macros",W,W,T,T,W,W,L,W,W,W,L,W,W,L,W,L,W,W,L,W,W,W,L,L
"Eastern",1,"NESUGgers",W,W,L,T,W,W,L,T,W,W,W,W,W,L,W,L,W,L,W,W,T,W,L,W
"Western",3,"West Coast WUSSers",W,L,W,W,W,T,L,W,W,W,L,W,W,L,W,L,W,T,W,T,W,W,L,W
"Western",3,"PNW Forecasters",W,W,L,W,T,W,L,T,W,W,T,W,W,L,W,L,W,W,W,L,W,W,W,L
"Central",2,"MWSUG Data Steppers",L,W,W,W,T,W,L,W,W,W,T,W,W,L,W,L,W,W,T,W,W,L,W,W
"Central",2,"Pharma Sluggers",W,L,W,T,L,W,L,W,W,W,L,W,W,L,W,W,L,W,L,W,T,W,W,L
;
run;

** You may need to download and register the Bissantz Spark Fonts;
** and then issue a PROC FONTREG for PDF if you get a font failure;
** message for PDF. Run PROC FONTREG after you install the Bissantz Fonts';
** as described here: http://support.sas.com/kb/16/071.html ;
ods listing close;
ods escapechar='~';
ods pdf file='complex4_sparkwins.pdf';
ods rtf file='complex4_sparkwins.rtf';
ods html file='complex4_sparkwins.html' style=sasweb;
proc report data=sasteams nowd ;
     title 'SAS Teams Win/Loss Record';
     title2 'Displayed 2 Different Ways';
     footnote1 "(~S={foreground=green}Green=Home Game; ~S={foreground=cx999999} Gray=Away Game~S={})";

     column divord Division TeamName 
            ('Record (24 Games)' sparkrec sparkcolr )
            wins ties losses;
     define divord / group noprint ;
     define division / group 'Division' style(column)={vjust=m};
     define TeamName / order 'Team' style(column)={vjust=m};;
     define sparkrec / display 'Sparkline 1 color'
            style(column)={font_face='Bissantz SparkFonts 4 - Misc'
                           font_size=30pt foreground=black};
     define sparkcolr / display 'Sparkline 2 colors'
            style(column)={font_size=30pt};
     define wins /sum style(column)={vjust=m} 'Wins';
     define ties/sum style(column)={vjust=m} 'Ties'; 
     define losses / sum style(column)={vjust=m} 'Losses'; 
run;
ods _all_ close;
ods listing;
title; footnote;



