ods listing;
title;
footnote;

%let outpath=C:\Courses\SAS_Global_Forum_2008\complex\output;
%let htout = .;

proc sort data=complex.DistrictSales out=DistrictSales;
by year district quarter;
run;

proc report data=DistrictSales nowd 
            out=work.grafinfo(keep=year district quarter sales SalesM);
  column year district quarter sales sales=SalesM;
  define year / group;
  define district / group;
  define quarter / group;
  define sales / sum;
  define salesM / sum;
  compute SalesM;
    SalesM=    round(sales.sum/1000000,1);
  endcomp;
run;

ods listing;

proc print data=grafinfo;
title 'grafinfo';
run;


proc format;
  value $qnum 'Q1'='1'
              'Q2'='2'
              'Q3'='3'
              'Q4'='4';
run;


**  Make some graphs ;
** delete the previous entries to ensure that the names are what;
** you want to set in the gseg catalog and/or in the file system.;

proc greplay igout = work.gseg nofs;
  delete _all_;
run;

** This ODS HTMLPANEL step is used to create the graphs and get the;
** SASWEB style applied to the graphs. This is different from the ;
** first example (4a) because it will only work for HTML.;

ods listing close;
ods path work.templ(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);
   
** This is where I stored the HTMLPANEL tagset template code;
** and the code must be run before the tagset can be used.;
%include 'c:\sas Programs\htmlpanel_examp\htmlpanel\htmlpanel.tpl';
%let panelcolumns = 2;
%let panelborder = 1;
%let embedded_titles=yes;

ods tagsets.htmlpanel path="&htout" (url=none) 
                      gpath="&htout" (url=none)
                      file="complex5c_smallmult_htmlpanel.html" 
                      style=sasweb;
goptions reset=all dev=javaimg xpixels=480 ypixels=320;

/* Start automatic paneling of graphs */

ods tagsets.htmlpanel event=panel(start);

axis1 order=(0 to 15 by 3);

proc gchart data=grafinfo;
  where district = 'Northern';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='North';
  label salesM='Northern' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;

proc gchart data=grafinfo;
  where district = 'Eastern';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='East';
  label salesM='Eastern' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;
 
proc gchart data=grafinfo;
  where district = 'Southern';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='South';
  label salesM='Southern' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;

proc gchart data=grafinfo;
  where district = 'Western';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='West';
  label salesM='Western' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;

/* Stop the paneling */
ods tagsets.htmlpanel event=panel(finish);

%let embedded_titles=no;

ods _all_ close;






