** Complex 8: Demographic Report Example;
** Uses Custom Table Template (covered in Advanced ODS class);
** Uses DATA _NULL_ with Custom Table Template ;

data other_demog;
length NYHA_Type $15;
  set complex.patient_info;
  keep NYHA_Type age lvef cadmi;
  ** create 3 categories for NYHA Type;
  if nyha in ('I', 'II', 'UNK') then
     NYHA_Type='I, II, UNK';
  else if nyha  = 'III' then NYHA_Type=nyha;
  else if nyha = 'IV' then NYHA_Type = nyha;
run;
ods listing;

proc tabulate data=other_demog out=ptsummary;
   class NYHA_Type CADMI;
   var Age;
   tables CADMI All,NYHA_Type*age*(n mean std min max median reppctn);
run;

proc print data=ptsummary;
run;

data _null_;
   set ptsummary;
   if _type_='10' then do;
      if NYHA_Type='I, II, UNK' then 
         call symput('t1','/NYHA I, II, UNK/(N='||put(Age_N,comma4.)||')');
      else if NYHA_Type='III' then 
         call symput('t2',"/NYHA III/(N="||put(Age_N,comma4.)||')');
      else if NYHA_Type='IV' then 
         call symput('t3',"/NYHA IV/(N="||put(Age_N,comma4.)||')');
   end;
run;

%let t1 = /~S={font_weight=bold font_style=roman}&t1;
%let t2 = /~S={font_weight=bold font_style=roman}&t2;
%let t3 = /~S={font_weight=bold font_style=roman}&t3;

%put &t1;
%put &t2; 
%put &t3;

ods path work.testtemp(update)
         sasuser.templat(update)
         sashelp.tmplmst(read);


proc template;
   define table demog;
      mvar t1 t2 t3;
      column RowLabel col1 col2 col3;
      define RowLabel;
         header=' ';
         cellstyle _val_ = 'Patient Age' as RowHeader{font_weight=bold},
                   _val_ = 'MI Categories' as RowHeader{font_weight=bold},
                   1 as Data{leftmargin=12pt};
      end;
      define col1;
         header=t1 just=C;
      end;
      define col2;
         header=t2 just=C;
      end;
      define col3;
         header=t3 just=C;
      end;
   end;
run;

proc format;
   picture num other='  009)'(prefix='(N=');
   picture pct other='009.9%)'(prefix='(');
run;

ods listing close;
ods rtf file='complex8_demog.rtf' style=journal;

ods escapechar='~';
data _null_;
   length RowLabel $20 col1 col2 col3 $ 120;
   title 'Demographic Report Using ODS and Table Templates';
   RowLabel=' ';
   col1=' ';
   col2=' ';
   col3=' ';
   set ptsummary;
   Age_M=left(trim(put(Age_Median,12.1)));
   Age_Num=left(trim(put(Age_N,12.)));
   file print ods=(template='demog') n=ps;
   if _type_='10' then do;
      MeanSD=left(trim(put(Age_Mean,4.1))||
                  ' ('||trim(put(Age_std,5.2))||')');
      MinMax=left(trim(put(Age_Min,3.))||
                  ', '||trim(put(Age_Max,3.)));
      put #2 @1 'Patient Age' /
             @1 'N' /
             @1 'Mean (SD)' / 
             @1 'Median' /
             @1 'Min, Max'/;            
      if NYHA_Type='I, II, UNK' then
         put #3 @2 Age_Num $12.-C /
                @2 MeanSD $12.-C /
                @2 Age_M $12.-C /
                @2 MinMax $12.-C;                
      else if NYHA_Type='III' then
         put #3 @3 Age_Num $12.-C/
                @3 MeanSD $12.-C /
                @3 Age_M $12.-C /
                @3 MinMax $12.-C;                
      else if NYHA_Type='IV' then
         put #3 @4 Age_Num $12.-C/
                @4 MeanSD $12.-C /
                @4 Age_M $12.-C /
                @4 MinMax $12.-C //
                @1 'MI Categories' ;                
   end;
   if _type_='11' then do;
      put #9 @1 'No' / 
          #10 @1 'Yes';
      Age_Info=right(put(Age_N,3.)||' '||left(put(Age_PctN_00,pct.)));
      if NYHA_Type='I, II, UNK' then do;
         if CADMI='0' then 
            put #9 @2 Age_Info;
         else
            put #10 @2 Age_Info;
      end; 
      else if NYHA_Type='III' then do;
         if CADMI='0' then 
            put #9 @3 Age_Info;
         else
            put #10 @3 Age_Info;
      end; 
      else if NYHA_Type='IV' then do;
         if CADMI='0' then 
            put #9 @4 Age_Info;
         else
            put #10 @4 Age_Info;
      end; 
   end;       
run;

ods rtf close;
ods listing;

title;
footnote;

