proc sort data=sashelp.class out=class;
  by sex name;
run;

ods listing close;
ods html file='figure1_2.html' style=egdefault;
proc print data=class n
  style(total)=Header
  style(n)=Header;
  by sex;
  id sex;
  var name age height;
run;

proc report data=class nowd
  style(summary) = Header
  style(lines) = Header;
  column sex name age height height=htn;
  define sex / group 
         style(column)=Header;
  define name / display;
  define age / display;
  define height / n noprint;
  define htn /sum;
  break after sex / page;
  rbreak after /;

  compute after sex;
    if sex = 'F' then 
       prtline = 'Female Students N ='||put(height.n,3.0);
    else if sex = 'M' then 
       prtline = 'Male Students N ='||put(height.n,3.0);
    line prtline $30.;
  endcomp;
  compute after;
    line 'Total N = ' height.n 3.0;
  endcomp;

run;

data _null_;
  length name $30;
  set class;
  by sex;
  where sex = 'F';
  file print ods=(variables=(sex name age height));
  cnt + 1;
  if first.sex then do;
    put @1 sex @2 name @3 age @4 height;
  end;
  else if not first.sex then do;
    put @2 name @3 age @4 height;
  end;
  if last.sex then do;
    put @2 "Female Student N = " @4 cnt 3.0;
  end;
  label name = 'Name'
        age = 'Age'
        height = 'Height'
        sex = 'Sex';
run;
ods html close;
